@@ -1,6 +1,21 @@
 #include <Rcpp.h>
 #include "shared.h"
-using namespace Rcpp;
+
+using std::pow;
+using std::sqrt;
+using std::abs;
+using std::exp;
+using std::log;
+using std::floor;
+using std::ceil;
+using std::sin;
+using std::cos;
+using std::tan;
+using std::atan;
+using Rcpp::IntegerVector;
+using Rcpp::NumericVector;
+using Rcpp::NumericMatrix;
+
 
 /*
  * Birnbaum-Saunders (Fatigue Life) Distribution
@@ -17,26 +32,26 @@ using namespace Rcpp;
  */
 
 double pdf_fatigue(double x, double alpha, double beta, double mu) {
-  if (alpha <= 0 || beta <= 0) {
+  if (alpha <= 0.0 || beta <= 0.0) {
     Rcpp::warning("NaNs produced");
     return NAN;
   }
   if (x <= mu || std::isinf(x))
-    return 0;
+    return 0.0;
   double z, zb, bz;
   z = x-mu;
   zb = sqrt(z/beta);
   bz = sqrt(beta/z);
-  return (zb+bz)/(2*alpha*z) * phi((zb-bz)/alpha);
+  return (zb+bz)/(2.0*alpha*z) * phi((zb-bz)/alpha);
 }
 
 double cdf_fatigue(double x, double alpha, double beta, double mu) {
-  if (alpha <= 0 || beta <= 0) {
+  if (alpha <= 0.0 || beta <= 0.0) {
     Rcpp::warning("NaNs produced");
     return NAN;
   }
   if (x <= mu)
-    return 0;
+    return 0.0;
   double z, zb, bz;
   z = x-mu;
   zb = sqrt(z/beta);
@@ -45,23 +60,23 @@ double cdf_fatigue(double x, double alpha, double beta, double mu) {
 }
 
 double invcdf_fatigue(double p, double alpha, double beta, double mu) {
-  if (alpha <= 0 || beta <= 0) {
+  if (alpha <= 0.0 || beta <= 0.0) {
     Rcpp::warning("NaNs produced");
     return NAN;
   }
-  if (p == 0)
+  if (p == 0.0)
     return mu;
   double Zp = InvPhi(p);
-  return pow(alpha/2*Zp + sqrt(pow(alpha/2*Zp, 2) + 1), 2) * beta + mu;
+  return pow(alpha/2.0*Zp + sqrt(pow(alpha/2.0*Zp, 2.0) + 1.0), 2.0) * beta + mu;
 }
 
 double rng_fatigue(double alpha, double beta, double mu) {
-  if (alpha <= 0 || beta <= 0) {
+  if (alpha <= 0.0 || beta <= 0.0) {
     Rcpp::warning("NaNs produced");
     return NAN;
   }
-  double z = R::rnorm(0, 1);
-  return pow(alpha/2*z + sqrt(pow(alpha/2*z, 2) + 1), 2) * beta + mu;
+  double z = R::rnorm(0.0, 1.0);
+  return pow(alpha/2.0*z + sqrt(pow(alpha/2.0*z, 2.0) + 1.0), 2.0) * beta + mu;
 }
 
 
@@ -113,7 +128,7 @@ NumericVector cpp_pfatigue(
   
   if (!lower_tail)
     for (int i = 0; i < Nmax; i++)
-      p[i] = 1-p[i];
+      p[i] = 1.0 - p[i];
   
   if (log_prob)
     for (int i = 0; i < Nmax; i++)
@@ -146,7 +161,7 @@ NumericVector cpp_qfatigue(
   
   if (!lower_tail)
     for (int i = 0; i < n; i++)
-      pp[i] = 1-pp[i];
+      pp[i] = 1.0 - pp[i];
   
   for (int i = 0; i < Nmax; i++)
     q[i] = invcdf_fatigue(pp[i % n], alpha[i % na], beta[i % nb], mu[i % nm]);
