@@ -1,5 +1,19 @@
 #include <Rcpp.h>
-using namespace Rcpp;
+
+using std::pow;
+using std::sqrt;
+using std::abs;
+using std::exp;
+using std::log;
+using std::floor;
+using std::ceil;
+using std::sin;
+using std::cos;
+using std::tan;
+using std::atan;
+using Rcpp::IntegerVector;
+using Rcpp::NumericVector;
+using Rcpp::NumericMatrix;
 
 
 /*
@@ -19,42 +33,42 @@ using namespace Rcpp;
 */
 
 double pdf_kumar(double x, double a, double b) {
-  if (a <= 0 || b <= 0) {
+  if (a <= 0.0 || b <= 0.0) {
     Rcpp::warning("NaNs produced");
     return NAN;
   }
-  if (x >= 0 && x <= 1)
-    return a*b * pow(x, a-1) * pow(1-pow(x, a), b-1);
+  if (x >= 0.0 && x <= 1.0)
+    return a*b * pow(x, a-1.0) * pow(1.0-pow(x, a), b-1.0);
   else
-    return 0;
+    return 0.0;
 }
 
 double cdf_kumar(double x, double a, double b) {
-  if (a <= 0 || b <= 0) {
+  if (a <= 0.0 || b <= 0.0) {
     Rcpp::warning("NaNs produced");
     return NAN;
   }
-  if (x >= 0 && x <= 1)
-    return 1 - pow(1 - pow(x, a), b);
+  if (x >= 0.0 && x <= 1.0)
+    return 1.0 - pow(1.0 - pow(x, a), b);
   else
-    return 0;
+    return 0.0;
 }
 
 double invcdf_kumar(double p, double a, double b) {
-  if (a <= 0 || b <= 0 || p < 0 || p > 1) {
+  if (a <= 0.0 || b <= 0.0 || p < 0.0 || p > 1.0) {
     Rcpp::warning("NaNs produced");
     return NAN;
   }
-  return pow(1 - pow(1-p, 1/b), 1/a);
+  return pow(1.0 - pow(1.0 - p, 1.0/b), 1.0/a);
 }
 
 double logpdf_kumar(double x, double a, double b) {
-  if (a <= 0 || b <= 0) {
+  if (a <= 0.0 || b <= 0.0) {
     Rcpp::warning("NaNs produced");
     return NAN;
   }
-  if (x >= 0 && x <= 1)
-    return log(a) + log(b) + log(x)*(a-1) + log(1-pow(x, a))*(b-1);
+  if (x >= 0.0 && x <= 1.0)
+    return log(a) + log(b) + log(x)*(a-1.0) + log(1.0 - pow(x, a))*(b-1.0);
   else
     return -INFINITY;
 }
@@ -104,7 +118,7 @@ NumericVector cpp_pkumar(
 
   if (!lower_tail)
     for (int i = 0; i < Nmax; i++)
-      p[i] = 1-p[i];
+      p[i] = 1.0 - p[i];
 
   if (log_prob)
     for (int i = 0; i < Nmax; i++)
@@ -135,7 +149,7 @@ NumericVector cpp_qkumar(
 
   if (!lower_tail)
     for (int i = 0; i < n; i++)
-      pp[i] = 1-pp[i];
+      pp[i] = 1.0 - pp[i];
 
   for (int i = 0; i < Nmax; i++)
     q[i] = invcdf_kumar(pp[i % n], a[i % na], b[i % nb]);
@@ -157,7 +171,7 @@ NumericVector cpp_rkumar(
   NumericVector x(n);
 
   for (int i = 0; i < n; i++) {
-    u = R::runif(0, 1);
+    u = R::runif(0.0, 1.0);
     x[i] = invcdf_kumar(u, a[i % na], b[i % nb]);
   }
 
