@@ -1,7 +1,21 @@
 #include <Rcpp.h>
 #include "const.h"
 #include "shared.h"
-using namespace Rcpp;
+
+using std::pow;
+using std::sqrt;
+using std::abs;
+using std::exp;
+using std::log;
+using std::floor;
+using std::ceil;
+using std::sin;
+using std::cos;
+using std::tan;
+using std::atan;
+using Rcpp::IntegerVector;
+using Rcpp::NumericVector;
+using Rcpp::NumericMatrix;
 
 
 /*
@@ -38,34 +52,34 @@ NumericVector cpp_dmnom(
   for (int i = 0; i < Nmax; i++) {
     
     double n_fac = lfactorial(size[i % ns]);
-    double prod_xfac = 0;
-    double prod_pow_px = 0;
+    double prod_xfac = 0.0;
+    double prod_pow_px = 0.0;
     
-    double sum_x = 0;
-    double sum_p = 0;
+    double sum_x = 0.0;
+    double sum_p = 0.0;
     bool wrong_p = false;
     bool wrong_x = false;
 
     for (int j = 0; j < k; j++) {
-      if (prob(i % np, j) < 0 || prob(i % np, j) > 1) {
+      if (prob(i % np, j) < 0.0 || prob(i % np, j) > 1.0) {
         wrong_p = true;
         break;
       }
-      if (x(i % n, j) < 0 || !isInteger(x(i % n, j))) {
+      if (x(i % n, j) < 0.0 || !isInteger(x(i % n, j))) {
         wrong_x = true;
       } else {
         sum_x += x(i % n, j);
-        prod_xfac += lfactorial(x(i % n, j));
+        prod_xfac += lfactorial(x(i % n, static_cast<double>(j)));
         prod_pow_px += log(prob(i % np, j)) * x(i % n, j);
       }
       sum_p += prob(i % np, j)*P_NORM_CONST;
     }
 
-    if (!tol_equal(sum_p/P_NORM_CONST, 1) || wrong_p) {
+    if (!tol_equal(sum_p/P_NORM_CONST, 1.0) || wrong_p) {
       Rcpp::warning("NaNs produced");
       p[i] = NAN; 
     } else if (floor(size[i % ns]) != size[i % ns] ||
-        sum_x < 0 || sum_x != size[i % ns] || wrong_x) {
+               sum_x < 0.0 || sum_x != size[i % ns] || wrong_x) {
       p[i] = -INFINITY;
     } else {
       p[i] = n_fac - prod_xfac + prod_pow_px;
@@ -95,12 +109,12 @@ NumericMatrix cpp_rmnom(
   
   for (int i = 0; i < n; i++) {
     
-    int size_left = size[i % ns];
-    double sum_p = 0;
+    double size_left = size[i % ns];
+    double sum_p = 0.0;
     bool wrong_p = false;
     
     for (int j = 0; j < k-1; j++) {
-      if (prob(i % np, j) < 0 || prob(i % np, j) > 1) {
+      if (prob(i % np, j) < 0.0 || prob(i % np, j) > 1.0) {
         wrong_p = true;
         break;
       }
@@ -112,7 +126,7 @@ NumericMatrix cpp_rmnom(
     x(i, k-1) = size_left;
     sum_p += prob(i % np, k-1)*P_NORM_CONST;
     
-    if (!tol_equal(sum_p/P_NORM_CONST, 1) || wrong_p) {
+    if (!tol_equal(sum_p/P_NORM_CONST, 1.0) || wrong_p) {
       Rcpp::warning("NaNs produced");
       for (int j = 0; j < k; j++)
         x(i, j) = NAN;
