@@ -1,5 +1,19 @@
 #include <Rcpp.h>
-using namespace Rcpp;
+
+using std::pow;
+using std::sqrt;
+using std::abs;
+using std::exp;
+using std::log;
+using std::floor;
+using std::ceil;
+using std::sin;
+using std::cos;
+using std::tan;
+using std::atan;
+using Rcpp::IntegerVector;
+using Rcpp::NumericVector;
+using Rcpp::NumericMatrix;
 
 
 /*
@@ -16,43 +30,43 @@ using namespace Rcpp;
 */
 
 double pdf_nst(double x, double nu, double mu, double sigma) {
-  if (nu <= 0 || sigma <= 0) {
+  if (nu <= 0.0 || sigma <= 0.0) {
     Rcpp::warning("NaNs produced");
     return NAN;
   }
-  if (nu == 1)
+  if (nu == 1.0)
     return R::dcauchy(x, mu, sigma, false);
   double z = (x - mu)/sigma;
   return R::dt(z, nu, false)/sigma;
 }
 
 double cdf_nst(double x, double nu, double mu, double sigma) {
-  if (nu <= 0 || sigma <= 0) {
+  if (nu <= 0.0 || sigma <= 0.0) {
     Rcpp::warning("NaNs produced");
     return NAN;
   }
-  if (nu == 1)
+  if (nu == 1.0)
     return R::pcauchy(x, mu, sigma, true, false);
   double z = (x - mu)/sigma;
   return R::pt(z, nu, true, false);
 }
 
 double invcdf_nst(double p, double nu, double mu, double sigma) {
-  if (nu <= 0 || sigma <= 0) {
+  if (nu <= 0.0 || sigma <= 0.0) {
     Rcpp::warning("NaNs produced");
     return NAN;
   }
-  if (nu == 1)
+  if (nu == 1.0)
     return R::qcauchy(p, mu, sigma, true, false);
   return R::qt(p, nu, true, false)*sigma + mu;
 }
 
 double rng_nst(double nu, double mu, double sigma) {
-  if (nu <= 0 || sigma <= 0) {
+  if (nu <= 0.0 || sigma <= 0.0) {
     Rcpp::warning("NaNs produced");
     return NAN;
   }
-  if (nu == 1)
+  if (nu == 1.0)
     return R::rcauchy(mu, sigma);
   return R::rt(nu)*sigma + mu;
 }
@@ -106,7 +120,7 @@ NumericVector cpp_pnst(
   
   if (!lower_tail)
     for (int i = 0; i < Nmax; i++)
-      p[i] = 1-p[i];
+      p[i] = 1.0 - p[i];
   
   if (log_prob)
     for (int i = 0; i < Nmax; i++)
@@ -139,7 +153,7 @@ NumericVector cpp_qnst(
   
   if (!lower_tail)
     for (int i = 0; i < n; i++)
-      pp[i] = 1-pp[i];
+      pp[i] = 1.0 - pp[i];
   
   for (int i = 0; i < Nmax; i++)
     q[i] = invcdf_nst(pp[i % n], nu[i % nn], mu[i % nm], sigma[i % ns]);
