@@ -1,5 +1,19 @@
 #include <Rcpp.h>
-using namespace Rcpp;
+
+using std::pow;
+using std::sqrt;
+using std::abs;
+using std::exp;
+using std::log;
+using std::floor;
+using std::ceil;
+using std::sin;
+using std::cos;
+using std::tan;
+using std::atan;
+using Rcpp::IntegerVector;
+using Rcpp::NumericVector;
+using Rcpp::NumericMatrix;
 
 
 /*
@@ -16,7 +30,7 @@ using namespace Rcpp;
 */
 
 double pdf_nsbeta(double x, double alpha, double beta, double l, double u, bool log_p) {
-  if (l >= u || alpha < 0 || beta < 0) {
+  if (l >= u || alpha < 0.0 || beta < 0.0) {
     Rcpp::warning("NaNs produced");
     return NAN;
   }
@@ -29,7 +43,7 @@ double pdf_nsbeta(double x, double alpha, double beta, double l, double u, bool
 }
 
 double cdf_nsbeta(double x, double alpha, double beta, double l, double u, bool lower_tail, bool log_p) {
-  if (l >= u || alpha < 0 || beta < 0) {
+  if (l >= u || alpha < 0.0 || beta < 0.0) {
     Rcpp::warning("NaNs produced");
     return NAN;
   }
@@ -37,7 +51,7 @@ double cdf_nsbeta(double x, double alpha, double beta, double l, double u, bool
 }
 
 double invcdf_nsbeta(double p, double alpha, double beta, double l, double u, bool lower_tail, bool log_p) {
-  if (l >= u || alpha < 0 || beta < 0) {
+  if (l >= u || alpha < 0.0 || beta < 0.0) {
     Rcpp::warning("NaNs produced");
     return NAN;
   }
@@ -45,7 +59,7 @@ double invcdf_nsbeta(double p, double alpha, double beta, double l, double u, bo
 }
 
 double rng_nsbeta(double alpha, double beta, double l, double u) {
-  if (l >= u || alpha < 0 || beta < 0) {
+  if (l >= u || alpha < 0.0 || beta < 0.0) {
     Rcpp::warning("NaNs produced");
     return NAN;
   }
