@@ -1,6 +1,21 @@
 #include <Rcpp.h>
 #include "shared.h"
-using namespace Rcpp;
+
+using std::pow;
+using std::sqrt;
+using std::abs;
+using std::exp;
+using std::log;
+using std::floor;
+using std::ceil;
+using std::sin;
+using std::cos;
+using std::tan;
+using std::atan;
+using Rcpp::IntegerVector;
+using Rcpp::NumericVector;
+using Rcpp::NumericMatrix;
+
 
 /*
  * Skellam distribution
@@ -11,17 +26,17 @@ using namespace Rcpp;
  */
 
 double pmf_skellam(double x, double mu1, double mu2) {
-  if (mu1 < 0 || mu2 <= 0) {
+  if (mu1 < 0.0 || mu2 <= 0.0) {
     Rcpp::warning("NaNs produced");
     return NAN;
   }
   if (!isInteger(x))
-    return 0;
-  return exp(-(mu1+mu2)) * pow(mu1/mu2, x/2) * R::bessel_i(2*sqrt(mu1*mu2), x, 1);
+    return 0.0;
+  return exp(-(mu1+mu2)) * pow(mu1/mu2, x/2.0) * R::bessel_i(2.0*sqrt(mu1*mu2), x, 1.0);
 }
 
 double rng_skellam(double mu1, double mu2) {
-  if (mu1 < 0 || mu2 <= 0) {
+  if (mu1 < 0.0 || mu2 <= 0.0) {
     Rcpp::warning("NaNs produced");
     return NAN;
   }
