@@ -1,6 +1,21 @@
 #include <Rcpp.h>
 #include "shared.h"
-using namespace Rcpp;
+
+using std::pow;
+using std::sqrt;
+using std::abs;
+using std::exp;
+using std::log;
+using std::floor;
+using std::ceil;
+using std::sin;
+using std::cos;
+using std::tan;
+using std::atan;
+using Rcpp::IntegerVector;
+using Rcpp::NumericVector;
+using Rcpp::NumericMatrix;
+
 
 /*
  * Location-scale slash distribution
@@ -14,33 +29,33 @@ using namespace Rcpp;
 
 
 double pdf_slash(double x, double mu, double sigma) {
-  if (sigma <= 0) {
+  if (sigma <= 0.0) {
     Rcpp::warning("NaNs produced");
     return NAN;
   }
   double z = (x - mu)/sigma;
-  return ((phi(0) - phi(z))/pow(z, 2))/sigma;
+  return ((phi(0.0) - phi(z))/pow(z, 2.0))/sigma;
 }
 
 double cdf_slash(double x, double mu, double sigma) {
-  if (sigma <= 0) {
+  if (sigma <= 0.0) {
     Rcpp::warning("NaNs produced");
     return NAN;
   }
   double z = (x - mu)/sigma;
-  if (z == 0)
+  if (z == 0.0)
     return 0.5;
   else
-    return Phi(z) - (phi(0) - phi(z))/z;
+    return Phi(z) - (phi(0.0) - phi(z))/z;
 }
 
 double rng_slash(double mu, double sigma) {
-  if (sigma <= 0) {
+  if (sigma <= 0.0) {
     Rcpp::warning("NaNs produced");
     return NAN;
   }
-  double z = R::rnorm(0, 1);
-  double u = R::runif(0, 1);
+  double z = R::rnorm(0.0, 1.0);
+  double u = R::runif(0.0, 1.0);
   return z/u*sigma + mu;
 }
 
@@ -90,7 +105,7 @@ NumericVector cpp_pslash(
   
   if (!lower_tail)
     for (int i = 0; i < Nmax; i++)
-      p[i] = 1-p[i];
+      p[i] = 1.0 - p[i];
   
   if (log_prob)
     for (int i = 0; i < Nmax; i++)
